/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IEJB3.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.io.Serializable;


/**
 * Defines the interface of the XML representation of an EJB 3 deployment
 * descriptor.
 * @author Florent Benoit
 */
public interface IEJB3 extends Serializable {

    /**
     * Gets the enterprise-beans element.
     * @return the enterprise-beans
     */
    IEnterpriseBeans getEnterpriseBeans();

    /**
     * Sets the enterprise-beans element.
     * @param enterpriseBeans the element to set.
     */
    void setEnterpriseBeans(final IEnterpriseBeans enterpriseBeans);

    /**
     * Gets the interceptors element.
     * @return the interceptors
     */
    IInterceptors getInterceptors();

    /**
     * Sets the interceptors element.
     * @param interceptors the element to set.
     */
    void setInterceptors(final IInterceptors interceptors);

    /**
     * Gets the assembly-descriptor element.
     * @return the assembly-descriptor
     */
    IAssemblyDescriptor getAssemblyDescriptor();

    /**
     * Sets the assembly-descriptor element.
     * @param assemblyDescriptor the element to set.
     */
    void setAssemblyDescriptor(final IAssemblyDescriptor assemblyDescriptor);

    /**
     * Set metadataComplete.
     * @param metadataComplete true if deployment descriptor contains all
     *        information
     */
    void setMetadataComplete(final boolean metadataComplete);

    /**
     * Get metadataComplete.
     * @return true if deployment descriptor contains all information
     */
    boolean isMetadataComplete();

}
