/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: IMessageDriven.java 4389 2008-12-15 13:48:57Z alitokmen $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.ejbjar.api.xml.struct;

import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IActivationConfig;


/**
 * Interface for element message-driven.
 * @author Florent Benoit
 */
public interface IMessageDriven extends IBean {

    /**
     * Name of this element.
     */
    String NAME = "message-driven";

    /**
     * Set the messaging-type.
     * @param messagingType the message listener interface of the message-driven
     *        bean.
     */
    void setMessagingType(final String messagingType);

    /**
     * Gets the messaging-type.
     * @return the messaging-type
     */
    String getMessagingType();

    /**
     * Set the message destination type.
     * @param messageDestinationType message destination type.
     */
    void setMessageDestinationType(final String messageDestinationType);

    /**
     * Gets the message destination type.
     * @return the message destination type
     */
    String getMessageDestinationType();

    /**
     * Set the message destination link.
     * @param messageDestinationLink message destination link.
     */
    void setMessageDestinationLink(final String messageDestinationLink);

    /**
     * Gets the message destination link.
     * @return the message destination link
     */
    String getMessageDestinationLink();

    /**
     * Gets the activation-config list.
     * @return activation-config list
     */
    List<IActivationConfig> getActivationConfigList();

    /**
     * Add the activation-config property.
     * @param activationConfig activation-config property
     */
    void addActivationConfig(final IActivationConfig activationConfig);

}
